import { BridgeParams } from "../interfaces/bridge-params";
import { ethers } from "ethers";
import { Web3Bridge } from "../bridge/web3-bridge";
import { CreateTransactionResponse } from "fireblocks-sdk";
import { ABIStructure } from "../types/abi";
export declare class BaseToken {
    private readonly _allFunctions;
    private readonly bridgeParams;
    contract: ethers.Contract;
    web3Bridge: Web3Bridge;
    contractABI: ABIStructure;
    address: string;
    constructor(bridgeParams: BridgeParams, contractABI: ABIStructure);
    /**
     * Use this to build a transaction which will then be sent to fireblocks to get signed.
     * @param abiName - abi function name
     * @param args - function params
     */
    buildTransaction(abiName: string, ...args: any[]): Promise<any>;
    /**
     * Use this to execute a function that needs no signing, e.g. supportsInterface. Basically a "read" function
     * @param abiName
     * @param args
     */
    callView(abiName: string, ...args: any[]): Promise<any>;
    /**
     * Fetching Fireblocks default address using chain
     */
    getAddress(): Promise<string>;
    /**
     * Submit transaction using Fireblocks infrastructure
     * @param transactionData
     * @param notes - (Optional) Add a note to the transaction
     */
    submitTransaction(transactionData: any, notes?: string): Promise<CreateTransactionResponse>;
}
