"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomToken = void 0;
const base_token_1 = require("./base-token");
class CustomToken extends base_token_1.BaseToken {
    constructor(bridgeParams, contractABI) {
        super(bridgeParams, contractABI);
    }
    /**
     * Will activate a read function from the provided Contract ABI
     * @param abiFunctionName
     * @param args - arguments for contract call (addresses should be wrapped with Web3.toChecksumAddress(address)
     */
    callReadFunction(abiFunctionName, ...args) {
        return this.callView(abiFunctionName, ...args);
    }
    /**
     * Will activate a write function from the provided Contract ABI using Fireblocks secure infrastructure
     * @param abiFunctionName
     * @param notes
     * @param args - arguments for contract call (addresses should be wrapped with Web3.toChecksumAddress(address)
     */
    async callWriteFunction(abiFunctionName, notes, ...args) {
        const transactionData = await this.buildTransaction(abiFunctionName, ...args, notes);
        return this.submitTransaction(transactionData, notes);
    }
}
exports.CustomToken = CustomToken;
