import { BaseToken } from "./base-token";
import { BridgeParams } from "../interfaces/bridge-params";
import { CreateTransactionResponse } from "fireblocks-sdk";
export declare class ERC1155 extends BaseToken {
    constructor(bridgeParams: BridgeParams);
    /** Payable **/
    /**
     * Length of token_ids and values must match. Moreover, the value of each token (at position x at [values]) to be
     * sent must match the same position at [token_ids] (position x). For example:
     * token_ids [3, 6, 10] and values [10, 20, 30] will send:
     *         - 10 tokens of token id 3
     *         - 20 tokens of token id 6
     *         - 30 tokens of token id 10
     * @param fromAddress - The sender of the address token.
     * @param toAddress - The receiver of the address token.
     * @param tokenIds - A list of token ids to transfer from sender to receiver.
     * @param values
     * @param data
     * @param note
     */
    safeBatchTransferFrom(toAddress: string, tokenIds: number[], values: number[], data?: Uint8Array, note?: string, fromAddress?: string): Promise<CreateTransactionResponse>;
    /**
     *
     * @param fromAddress - The sender of the address token.
     * @param toAddress - The receiver of the address token.
     * @param tokenId - The ID of the sender address token.
     * @param data - Send additional data (bytes) only if required by contract.
     * @param note
     */
    safeTransferFrom(toAddress: string, tokenId: number, data?: Uint8Array, note?: string, fromAddress?: string): Promise<CreateTransactionResponse>;
    /**
     * Provide an operator with approval permission or revoke them
     * @param operatorAddress - Approved operator address
     * @param isApproved - True to permit, False to revoke
     * @param notes - (Optional) Add a note to the transaction
     */
    setApprovalForAll(operatorAddress: string, isApproved: boolean, notes?: string): Promise<CreateTransactionResponse>;
    /** Views **/
    /**
     * Checks if contract supports a certain interface.
     * @param interfaceId - (Optional) The interface id. "0x80ac58cd" is ERC721 interface id. "0xd9b67a26" is ERC1155
     */
    supportsInterface(interfaceId?: string): Promise<boolean>;
    /**
     *
     * @param tokenId
     * @param ownerAddress
     */
    balanceOf(tokenId: number, ownerAddress?: string): Promise<number>;
    /**
     *
     * @param ownersList -  A list of addresses
     * @param idList - A list of token Ids
     */
    balanceOfBatch(idList: number[], ownersList?: string[]): Promise<number[]>;
    /**
     * Validates whether an operator has been approved by a stated owner.
     * @param ownerAddress - Address of the owner.
     * @param operatorAddress - Address of the meant to be operator.
     * return: True whether operator is approved, False otherwise
     */
    isApprovedForAll(operatorAddress: string, ownerAddress?: string): Promise<boolean>;
    /**
     * Returns Token URI
     * @param tokenId
     */
    uri(tokenId: number): Promise<string>;
}
