"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ERC721 = void 0;
const base_token_1 = require("./base-token");
const base_abis_1 = require("../constants/base-abis");
const web3_1 = __importDefault(require("web3"));
class ERC721 extends base_token_1.BaseToken {
    constructor(bridgeParams) {
        super(bridgeParams, base_abis_1.ERC721_ABI);
    }
    /** Payable **/
    /**
     *
     * @param toAddress
     * @param tokenId
     * @param note
     */
    async approve(toAddress, tokenId, note = "") {
        const checkedToAddress = web3_1.default.utils.toChecksumAddress(toAddress);
        const transactionData = await this.buildTransaction("approve", checkedToAddress, tokenId);
        return this.submitTransaction(transactionData, note);
    }
    /**
     *
     * @param fromAddress
     * @param toAddress
     * @param tokenId
     * @param data
     * @param note
     */
    async safeTransferFrom(toAddress, tokenId, data, note = "", fromAddress) {
        let transactionData;
        const checkedFromAddress = web3_1.default.utils.toChecksumAddress(fromAddress || await this.getAddress());
        const checkedToAddress = web3_1.default.utils.toChecksumAddress(toAddress);
        if (data) {
            transactionData = await this.contract.populateTransaction['safeTransferFrom(address,address,uint256,bytes)'](checkedFromAddress, checkedToAddress, tokenId, data);
        }
        else {
            transactionData = await this.contract.populateTransaction["safeTransferFrom(address,address,uint256)"](checkedFromAddress, checkedToAddress, tokenId);
        }
        transactionData.from = checkedFromAddress;
        return this.submitTransaction(transactionData, note);
    }
    /**
     *
     * @param fromAddress
     * @param toAddress
     * @param tokenId
     * @param note
     */
    async transferFrom(toAddress, tokenId, note = "", fromAddress) {
        const checkedFromAddress = web3_1.default.utils.toChecksumAddress(fromAddress || await this.getAddress());
        const checkedToAddress = web3_1.default.utils.toChecksumAddress(toAddress);
        const transactionData = await this.buildTransaction("transferFrom", checkedFromAddress, checkedToAddress, tokenId);
        return this.submitTransaction(transactionData, note);
    }
    /**
     *
     * @param operatorAddress
     * @param isApproved
     * @param note
     */
    async setApprovalForAll(operatorAddress, isApproved, note = "") {
        const checkedOperatorAddress = web3_1.default.utils.toChecksumAddress(operatorAddress);
        return this.submitTransaction(await this.buildTransaction("setApprovalForAll", checkedOperatorAddress, isApproved), note);
    }
    /** Views **/
    /**
     *
     * @param interfaceId
     */
    supportsInterface(interfaceId = '0x80ac58cd') {
        return this.callView("supportsInterface", interfaceId);
    }
    /**
     *
     * @param tokenId
     */
    getApproved(tokenId) {
        return this.callView("getApproved", tokenId);
    }
    /**
     *
     * @param ownerAddress
     * @param operatorAddress
     */
    isApprovedForAll(ownerAddress, operatorAddress) {
        const ownerCheckedAddress = web3_1.default.utils.toChecksumAddress(ownerAddress);
        const operatorCheckedAddress = web3_1.default.utils.toChecksumAddress(operatorAddress);
        return this.callView("isApprovedForAll", ownerCheckedAddress, operatorCheckedAddress);
    }
    /**
     *
     * @param ownerAddress
     */
    async balanceOf(ownerAddress) {
        const ownerCheckedAddress = web3_1.default.utils.toChecksumAddress(ownerAddress || await this.getAddress());
        return this.callView("balanceOf", ownerCheckedAddress);
    }
    /**
     *
     * @param tokenId
     */
    ownerOf(tokenId) {
        return this.callView("ownerOf", tokenId);
    }
}
exports.ERC721 = ERC721;
