"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseToken = void 0;
const ethers_1 = require("ethers");
const web3_bridge_1 = require("../bridge/web3-bridge");
class BaseToken {
    constructor(bridgeParams, contractABI) {
        if (!bridgeParams.chain) {
            throw new Error('Token must contain chain');
        }
        this.bridgeParams = bridgeParams;
        this.web3Bridge = new web3_bridge_1.Web3Bridge(this.bridgeParams);
        this.contractABI = contractABI;
        this.contract = new ethers_1.ethers.Contract(this.bridgeParams.externalWalletId, this.contractABI, ethers_1.ethers.getDefaultProvider(this.bridgeParams.chain));
        this._allFunctions = this.contract.functions;
    }
    /**
     * Use this to build a transaction which will then be sent to fireblocks to get signed.
     * @param abiName - abi function name
     * @param args - function params
     */
    buildTransaction(abiName, ...args) {
        return this.contract[abiName].call(...args).buildTransaction();
    }
    /**
     * Use this to execute a function that needs no signing, e.g. supportsInterface. Basically a "read" function
     * @param abiName
     * @param args
     */
    callView(abiName, ...args) {
        var _a;
        return (_a = this.contract[abiName]) === null || _a === void 0 ? void 0 : _a.call(...args);
    }
    /**
     * Submit transaction using defi SDK
     * @param transactionData
     * @param notes - (Optional) Add a note to the transaction
     */
    submitTransaction(transactionData, notes) {
        return this.web3Bridge.sendTransaction(transactionData, notes);
    }
}
exports.BaseToken = BaseToken;
