"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ERC721 = void 0;
const base_token_1 = require("./base-token");
const base_abis_1 = require("../constants/base-abis");
const web3_1 = require("web3");
class ERC721 extends base_token_1.BaseToken {
    constructor(bridgeParams) {
        super(bridgeParams, base_abis_1.ERC721_ABI);
    }
    /** Payable **/
    /**
     *
     * @param toAddress
     * @param tokenId
     * @param note
     */
    approve(toAddress, tokenId, note = "") {
        return this.submitTransaction(this.buildTransaction("approve", toAddress, tokenId), note);
    }
    /**
     *
     * @param fromAddress
     * @param toAddress
     * @param tokenId
     * @param data
     * @param note
     */
    safeTransferFrom(fromAddress, toAddress, tokenId, data = "", note = "") {
        if (data) {
            return this.submitTransaction(this.buildTransaction("safeTransferFrom", fromAddress, toAddress, tokenId, data), note);
        }
        return this.submitTransaction(this.buildTransaction("safeTransferFrom", fromAddress, toAddress, tokenId), note);
    }
    /**
     *
     * @param fromAddress
     * @param toAddress
     * @param tokenId
     * @param note
     */
    transfer_from(fromAddress, toAddress, tokenId, note = "") {
        const checkedFromAddress = web3_1.default.utils.toChecksumAddress(fromAddress);
        const checkedToAddress = web3_1.default.utils.checkAddressChecksum(toAddress);
        return this.submitTransaction(this.buildTransaction("transferFrom", checkedFromAddress, checkedToAddress, tokenId), note);
    }
    /**
     *
     * @param operatorAddress
     * @param isApproved
     * @param note
     */
    set_approval_for_all(operatorAddress, isApproved, note = "") {
        const checkedOperatorAddress = web3_1.default.utils.toChecksumAddress(operatorAddress);
        return this.submitTransaction(this.buildTransaction("setApprovalForAll", checkedOperatorAddress, isApproved, note), note);
    }
    /** Views **/
    /**
     *
     * @param interfaceId
     */
    supportsInterface(interfaceId = "0x80ac58cd") {
        return this.callView("supportsInterface", interfaceId);
    }
    /**
     *
     * @param tokenId
     */
    getApproved(tokenId) {
        return this.callView("getApproved", tokenId);
    }
    /**
     *
     * @param ownerAddress
     * @param operatorAddress
     */
    isApprovedForAll(ownerAddress, operatorAddress) {
        const ownerCheckedAddress = web3_1.default.utils.toChecksumAddress(ownerAddress);
        const operatorCheckedAddress = web3_1.default.utils.toChecksumAddress(operatorAddress);
        return this.callView("isApprovedForAll", ownerCheckedAddress, operatorCheckedAddress);
    }
    /**
     *
     * @param ownerAddress
     */
    balanceOf(ownerAddress) {
        const ownerCheckedAddress = web3_1.default.utils.toChecksumAddress(ownerAddress);
        return this.callView("balanceOf", ownerCheckedAddress);
    }
    /**
     *
     * @param tokenId
     */
    ownerOf(tokenId) {
        return this.callView("ownerOf", tokenId);
    }
}
exports.ERC721 = ERC721;
